@@ -1,6 +1,7 @@
-from .ihex import parseIHex
-from .loader import Loader
-from .device import device_list
+from asaloader.ihex import parseIHex
+from asaloader.loader import Loader
+from asaloader.device import device_list
+from asaloader.locale import _
 
 import progressbar
 import serial
@@ -10,14 +11,6 @@ import math
 
 def do_prog(args):
 
-    # flash_data = b''
-    # if args.is_prog_flash:
-    #     flash_data = parseIHex(args.flash_file)
-
-    # eep_data = b''
-    # if args.is_prog_eep:
-    #     eep_data = parseIHex(args.eep_file)
-
     ser = serial.Serial()
     ser.port = args.port
     ser.baudrate = 115200
@@ -25,7 +18,7 @@ def do_prog(args):
     try:
         ser.open()
     except:
-        print("錯誤：串列埠 {0} 已經被占用".format(args.port))
+        print(_('ERROR: com port has been opened by another application.').format(args.port))
         sys.exit(1)
     
     loader = Loader(ser, args)
@@ -37,10 +30,11 @@ def do_prog(args):
     # print('預估花費時間為 {0} s。'.format(cost_t))
 
     widgets=[
-        ' [', progressbar.Timer('Elapsed Time: %(seconds)s s', ), '] ',
+        ' [', progressbar.Timer(_('Elapsed Time: %(seconds)s s'), ), '] ',
         progressbar.Bar(),
         progressbar.Counter(format='%(percentage)0.2f%%'),
     ]
+    
     bar = progressbar.ProgressBar(max_value=loader.total_steps, widgets=widgets)
     bar.update(0)
     for i in range(loader.total_steps):
